/*******************************************************************************
 * Copyright (c) 2003, 2007 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/

/*
 * Created on : 25.06.2003
 * Created by : s3595
 */
package at.spardat.xma.boot.logger;

/**
 * LogRecord
 *
 * @author <a href="mailto:schaeferc@spardat.at">s3595 Chr. Schaefer (CGS)</a>
 * @version $Id: LogRecord.java 2084 2007-11-27 14:53:31Z s3460 $
 *
 */
public class LogRecord implements java.io.Serializable {

    /**
     * @serial Logging message level
     */
    private LogLevel level;

    /**
     * @serial Class that issued logging call
     */
    private String sourceClassName;

    /**
     * @serial Method that issued logging call
     */
    private String sourceMethodName;

    /**
     * @serial Non-localized raw message text
     */
    private String message;

    /**
     * @serial Event time in milliseconds since 1970
     */
    private long millis;

    /**
     * @serial The Throwable (if any) associated with log message
     */
    private Throwable thrown;

    /**
     * @serial Name of the source Logger.
     */
    private String loggerName;

    private transient Object parameters[];


    /**
     * Get the parameters to the log message.
     *
     * @return the log message parameters.  May be null if
     *          there are no parameters.
     */
    public Object[] getParameters() {
    return parameters;
    }

    /**
     * Set the parameters to the log message.
     *
     * @param parameters the log message parameters.
     */
    public void setParameters(Object parameters[]) {
    this.parameters = parameters;
    }



    /**
     * Construct a LogRecord with the given level and message values.
     * <p>
     * The sequence property will be initialized with a new unique value.
     * These sequence values are allocated in increasing order within a VM.
     * <p>
     * The millis property will be initialized to the current time.
     * <p>
     * The thread ID property will be initialized with a unique ID for
     * the current thread.
     * <p>
     * All other properties will be initialized to "null".
     *
     * @param level  a logging level value
     * @param msg  the raw non-localized logging message
     */
    public LogRecord(LogLevel level, String msg) {
        this.level = level;
        message = msg;
        millis = System.currentTimeMillis();
    }

    /**
     * Get the source Logger name's
     *
     * @return source logger name (may be null)
     */
    public String getLoggerName() {
    return loggerName;
    }

    public String getLevelName() {
        return level.getName();
    }

    /**
     * Set the source Logger name.
     *
     * @param name   the source logger name (may be null)
     */
    public void setLoggerName(String name) {
    loggerName = name;
    }

    /**
     * Get the logging message level, for example Level.SEVERE.
     * @return the logging message level
     */
    public LogLevel getLevel() {
    return level;
    }

    /**
     * Set the logging message level, for example Level.SEVERE.
     * @param level the logging message level
     */
    public void setLevel(LogLevel level) {
    if (level == null) {
        throw new NullPointerException();
    }
    this.level = level;
    }

    public String getSourceClassName() {
        return sourceClassName;
    }

    /**
     * Set the name of the class that (allegedly) issued the logging request.
     *
     * @param sourceClassName the source class name
     */
    public void setSourceClassName(String sourceClassName) {
        this.sourceClassName = sourceClassName;
    }

    public String getSourceMethodName() {
        return sourceMethodName;
    }

    public void setSourceMethodName(String sourceMethodName) {
        this.sourceMethodName = sourceMethodName;
    }

    public String getMessage() {
    return message;
    }

    /**
     * Set the "raw" log message, before localization or formatting.
     *
     * @param message the raw message string
     */
    public void setMessage(String message) {
    this.message = message;
    }

    /**
     * Get event time in milliseconds since 1970.
     *
     * @return event time in millis since 1970
     */
    public long getMillis() {
        return millis;
    }

    /**
     * Set event time.
     *
     * @param millis event time in millis since 1970
     */
    public void setMillis(long millis) {
        this.millis = millis;
    }

    /**
     * Get any throwable associated with the log record.
     * <p>
     * If the event involved an exception, this will be the
     * exception object. Otherwise null.
     *
     * @return a throwable
     */
    public Throwable getThrown() {
        return thrown;
    }

    /**
     * Set a throwable associated with the log event.
     *
     * @param thrown a throwable
     */
    public void setThrown(Throwable thrown) {
    this.thrown = thrown;
    }


}



