/*******************************************************************************
 * Copyright (c) 2003, 2007 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/

/*
 * Created on 16.05.2003
 */
package at.spardat.xma.boot.transport;


/**
 * Thrown by Transport, if anything goes wrong in the communication with the server, after
 * the server propably changed its state.
 *
 * @author s2877
 */
public class ServerException extends CommunicationException {

    /**
     * Constructs an <code>ServerException</code> with the specified detail
     * Exception. The message of the detail exception is used as message of the
     * <code>ServerException</code>.
     *
     * @param exc the detail exception.
     */
    public ServerException(Exception exc) {
        super(exc);
    }

    /**
     * Constructs an <code>ServerException</code> with the specified detail
     * message.
     *
     * @param   message the detail message.
     */
    public ServerException(String message) {
        super(message);
    }

    /**
     * Constructs an <code>ServerException</code> with the specified mesage and detail
     * Exception.
     *
     * @param   message the detail message.
     * @param exc the detail exception.
     */
    public ServerException(String message,Exception exc) {
        super(message,exc);
    }

    /**
     * Constructs an <code>ServerException</code> with the specified detail
     * Exception and Http-Returncode. The message of the <code>ServerException</code>
     * is composed of the message of the detail exception and the returncode.
     *
     * @param exc the detail exception
     * @param returnCode the HTTP-Returncode send by the server
     */
    public ServerException(Exception exc,int returnCode) {
        super(exc,returnCode);
    }

    /**
     * Constructs an <code>ServerException</code> with the specified detail
     * message and Http-Returncode. The message of the <code>ServerException</code>
     * is composed of the detail message and the returncode.
     *
     * @param message the detail message
     * @param returnCode the HTTP-Returncode send by the server
     */
    public ServerException(String message,int returnCode) {
        super(message,returnCode);
    }

    /**
     * Constructs an <code>ServerException</code> with the specified message, detail
     * Exception and Http-Returncode. The message of the <code>ServerException</code>
     * is composed of the detail message and the returncode.
     *
     * @param message the detail message
     * @param exc the detail exception
     * @param returnCode the HTTP-Returncode send by the server
     */
    public ServerException(String message,Exception exc,int returnCode) {
        super(message,exc,returnCode);
    }

    /**
     * Constructs an <code>ServerException</code> with the specified Http-Returncode.
     * The message of the <code>ServerException</code>
     * is composed of the returncode.
     *
     * @param returnCode the HTTP-Returncode send by the server
     */
    public ServerException(int returnCode) {
        super(returnCode);
    }
}
